@@ -54,12 +54,12 @@ def submit(ctxtype, graph, config=None, username=None, password=None):
     Args:
         ctxtype(str): Type of context the application will be submitted to. A value from :py:class:`ContextTypes`.
         graph(Topology): The application topology to be submitted.
-        config(dict): Configuration for the submission.
+        config(dict): Configuration for the submission, augmented with values such as a :py:class:`JobConfig` or keys from :py:class:`ConfigParams`.
         username(str): Deprecated: Username for the Streams REST api. Use environment variable ``STREAMS_USERNAME`` if using user-password authentication.
         password(str): Deprecated: Password for `username`. Use environment variable ``STREAMS_PASSWORD`` if using user-password authentication.
 
     Returns:
-        SubmissionResult: Result of the submission. For details of what is contained see the :py:class:`ContextTypes`
+        SubmissionResult: Result of the submission. Content depends on :py:class:`ContextTypes`
         constant passed as `ctxtype`.
     """
     streamsx._streams._version._mismatch_check(__name__)
@@ -136,6 +136,12 @@ class _BaseSubmitter(object):
             # Make copy of config to avoid modifying
             # the callers config
             self.config.update(config)
+            # When SERVICE_DEFINITION is a String, it is assumed that 
+            # it is JSON SAS credentials, which must be converted to a JSON object
+            service_def = self.config.get(ConfigParams.SERVICE_DEFINITION)
+            if service_def:
+                if isinstance(service_def, str):
+                    self.config[ConfigParams.SERVICE_DEFINITION] = json.loads(service_def)
         self.config['contextType'] = str(self.ctxtype)
         if 'originator' not in self.config:
             self.config['originator'] = 'topology-' + __version__ + ':python-' + platform.python_version()
@@ -827,7 +833,7 @@ class ContextTypes(object):
     Environment variables:
         These environment variables define how the application is built and submitted.
 
-        * **STREAMS_INSTALL** - (optional) Location of a IBM Streams installation (4.0.1 or later). The install must be running on RedHat/CentOS 6 and `x86_64` architecture.
+        * **STREAMS_INSTALL** - (optional) Location of a IBM Streams installation (4.0.1 or later). The install must be running on RedHat/CentOS 7 and `x86_64` architecture.
 
     """
     DISTRIBUTED = 'DISTRIBUTED'
@@ -1068,8 +1074,12 @@ class ConfigParams(object):
     """Streaming Analytics service definition.
     Identifies the Streaming Analytics service to use. The definition can be one of
 
-        * The `service credentials` copied from the `Service credentials` page of the service console (not the Streams console). Credentials are provided in JSON format. They contain such as the API key and secret, as well as connection information for the service. 
-        * A JSON object (`dict`) of the form: ``{ "type": "streaming-analytics", "name": "service name", "credentials": {...} }`` with the `service credentials` as the value of the ``credentials`` key.
+        * The `service credentials` copied from the `Service credentials` page of the service console (not the Streams console).
+          Credentials are provided in JSON format. They contain such as the API key and secret, as well as connection information for the service.
+        * A JSON object (`dict`) created from the `service credentials`, for example with `json.loads(service_credentials)`
+        * A JSON object (`dict`) of the form: ``{ "type": "streaming-analytics", "name": "service name", "credentials": ... }``
+          with the `service credentials` as the value of the ``credentials`` key. The value of the ``credentials`` key can
+          be a JSON object (`dict`) or a `str` copied from the `Service credentials` page of the service console.
 
     This key takes precedence over :py:const:`VCAP_SERVICES` and :py:const:`SERVICE_NAME`.
 
@@ -1439,7 +1449,28 @@ class JobConfig(object):
 
 class SubmissionResult(object):
     """Passed back to the user after a call to submit.
-    Allows the user to use dot notation to access dictionary elements."""
+    Allows the user to use dot notation to access dictionary elements.
+
+    Example accessing result files when using :py:const:`~ContextTypes.BUNDLE`::
+
+        submission_result = submit(ContextTypes.BUNDLE, topology, config)
+        print(submission_result.bundlePath)
+        ...
+        os.remove(submission_result.bundlePath)
+        os.remove(submission_result.jobConfigPath)
+
+    Result contains the generated toolkit location when using :py:const:`~ContextTypes.TOOLKIT`::
+
+        submission_result = submit(ContextTypes.TOOLKIT, topology, config)
+        print(submission_result.toolkitRoot)
+
+    Result when using :py:const:`~ContextTypes.DISTRIBUTED` depends if the `Topology` is compiled locally and the resultant Streams application bundle
+    (sab file) is submitted to an IBM Streams instance or if the `Topology` is compiled on build-service and submitted to an instance in Cloud Pak for Data::
+
+        submission_result = submit(ContextTypes.DISTRIBUTED, topology, config)
+        print(submission_result)
+
+"""
     def __init__(self, results):
         self.results = results
         self._submitter = None
@@ -1557,7 +1588,7 @@ def _vcap_from_service_definition(service_def):
         credentials = service_def
 
     service = {}
-    service['credentials'] = credentials
+    service['credentials'] = credentials if isinstance(credentials, dict) else json.loads(credentials)
     service['name'] = _name_from_service_definition(service_def)
     vcap = {'streaming-analytics': [service]}
     return vcap
